aboutsummaryrefslogtreecommitdiffstats
path: root/policy-endpoints/src/main/java/org/onap/policy/common/endpoints/event/comm/TopicEndpoint.java
diff options
context:
space:
mode:
Diffstat (limited to 'policy-endpoints/src/main/java/org/onap/policy/common/endpoints/event/comm/TopicEndpoint.java')
-rw-r--r--policy-endpoints/src/main/java/org/onap/policy/common/endpoints/event/comm/TopicEndpoint.java82
1 files changed, 20 insertions, 62 deletions
diff --git a/policy-endpoints/src/main/java/org/onap/policy/common/endpoints/event/comm/TopicEndpoint.java b/policy-endpoints/src/main/java/org/onap/policy/common/endpoints/event/comm/TopicEndpoint.java
index bb707523..bf261def 100644
--- a/policy-endpoints/src/main/java/org/onap/policy/common/endpoints/event/comm/TopicEndpoint.java
+++ b/policy-endpoints/src/main/java/org/onap/policy/common/endpoints/event/comm/TopicEndpoint.java
@@ -3,6 +3,7 @@
* ONAP
* ================================================================================
* Copyright (C) 2017-2019 AT&T Intellectual Property. All rights reserved.
+ * Copyright (C) 2022,2024 Nordix Foundation.
* ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -24,17 +25,15 @@ import java.util.List;
import java.util.Properties;
import org.onap.policy.common.capabilities.Lockable;
import org.onap.policy.common.capabilities.Startable;
-import org.onap.policy.common.endpoints.event.comm.bus.DmaapTopicSink;
-import org.onap.policy.common.endpoints.event.comm.bus.DmaapTopicSource;
+import org.onap.policy.common.endpoints.event.comm.bus.KafkaTopicSink;
+import org.onap.policy.common.endpoints.event.comm.bus.KafkaTopicSource;
import org.onap.policy.common.endpoints.event.comm.bus.NoopTopicSink;
import org.onap.policy.common.endpoints.event.comm.bus.NoopTopicSource;
-import org.onap.policy.common.endpoints.event.comm.bus.UebTopicSink;
-import org.onap.policy.common.endpoints.event.comm.bus.UebTopicSource;
import org.onap.policy.common.endpoints.parameters.TopicParameterGroup;
import org.onap.policy.common.endpoints.parameters.TopicParameters;
/**
- * Abstraction to managed the system's Networked Topic Endpoints, sources of all events input into
+ * Abstraction to manage the system's Networked Topic Endpoints, sources of all events input into
* the System.
*/
public interface TopicEndpoint extends Startable, Lockable {
@@ -128,36 +127,20 @@ public interface TopicEndpoint extends Startable, Lockable {
TopicSource getTopicSource(Topic.CommInfrastructure commType, String topicName);
/**
- * Get the UEB Topic Source for the given topic name.
- *
- * @param topicName the topic name
- *
- * @return the UEB Topic Source
- * @throws IllegalStateException if the entity is in an invalid state, for example multiple
- * TopicReaders for a topic name and communication infrastructure
- * @throws IllegalArgumentException if invalid parameters are present
- */
- UebTopicSource getUebTopicSource(String topicName);
-
- /**
- * Get the DMAAP Topic Source for the given topic name.
- *
- * @param topicName the topic name
+ * Get the Noop Source for the given topic name.
*
- * @return the DMAAP Topic Source
- * @throws IllegalStateException if the entity is in an invalid state, for example multiple
- * TopicReaders for a topic name and communication infrastructure
- * @throws IllegalArgumentException if invalid parameters are present
+ * @param topicName the topic name.
+ * @return the Noop Source.
*/
- DmaapTopicSource getDmaapTopicSource(String topicName);
+ NoopTopicSource getNoopTopicSource(String topicName);
/**
* Get the Noop Source for the given topic name.
*
* @param topicName the topic name.
* @return the Noop Source.
*/
- NoopTopicSource getNoopTopicSource(String topicName);
+ KafkaTopicSource getKafkaTopicSource(String topicName);
/**
* Get the Topic Sinks for the given topic name.
@@ -201,18 +184,6 @@ public interface TopicEndpoint extends Startable, Lockable {
TopicSink getTopicSink(Topic.CommInfrastructure commType, String topicName);
/**
- * Get the UEB Topic Source for the given topic name.
- *
- * @param topicName the topic name
- *
- * @return the Topic Source
- * @throws IllegalStateException if the entity is in an invalid state, for example multiple
- * TopicReaders for a topic name and communication infrastructure
- * @throws IllegalArgumentException if invalid parameters are present
- */
- UebTopicSink getUebTopicSink(String topicName);
-
- /**
* Get the no-op Topic Sink for the given topic name.
*
* @param topicName the topic name
@@ -225,7 +196,7 @@ public interface TopicEndpoint extends Startable, Lockable {
NoopTopicSink getNoopTopicSink(String topicName);
/**
* Get the DMAAP Topic Source for the given topic name.
*
* @param topicName the topic name
*
@@ -234,21 +205,14 @@ public interface TopicEndpoint extends Startable, Lockable {
* TopicReaders for a topic name and communication infrastructure
* @throws IllegalArgumentException if invalid parameters are present
*/
- DmaapTopicSink getDmaapTopicSink(String topicName);
-
- /**
- * Gets only the UEB Topic Sources.
- *
- * @return the UEB Topic Source List
- */
- List<UebTopicSource> getUebTopicSources();
+ KafkaTopicSink getKafkaTopicSink(String topicName);
/**
* Gets only the DMAAP Topic Sources.
*
* @return the DMAAP Topic Source List
*/
- List<DmaapTopicSource> getDmaapTopicSources();
+ List<KafkaTopicSource> getKafkaTopicSources();
/**
* Gets only the NOOP Topic Sources.
@@ -258,18 +222,11 @@ public interface TopicEndpoint extends Startable, Lockable {
List<NoopTopicSource> getNoopTopicSources();
/**
* Gets only the UEB Topic Sinks.
*
* @return the UEB Topic Sink List
*/
- List<UebTopicSink> getUebTopicSinks();
-
- /**
- * Gets only the DMAAP Topic Sinks.
- *
- * @return the DMAAP Topic Sink List
- */
- List<DmaapTopicSink> getDmaapTopicSinks();
+ List<KafkaTopicSink> getKafkaTopicSinks();
/**
* Gets only the NOOP Topic Sinks.
@@ -277,4 +234,5 @@ public interface TopicEndpoint extends Startable, Lockable {
* @return the NOOP Topic Sinks List
*/
List<NoopTopicSink> getNoopTopicSinks();
+
}
@@ -128,36 +127,20 @@ public interface TopicEndpoint extends Startable, Lockable {
/**
- * Get the Noop Source for the given topic name.
+ * Get the Kafka Source for the given topic name.
*
* @param topicName the topic name.
@@ -128,36 +127,20 @@ public interface TopicEndpoint extends Startable, Lockable {
*
* @param topicName the topic name.
- * @return the Noop Source.
+ * @return the Kafka Source.
*/
@@ -225,7 +196,7 @@ public interface TopicEndpoint extends Startable, Lockable {
NoopTopicSink getNoopTopicSink(String topicName);
/**
- * Get the DMAAP Topic Source for the given topic name.
+ * Get the KAFKA Topic Source for the given topic name.
*
* @param topicName the topic name
@@ -234,21 +205,14 @@ public interface TopicEndpoint extends Startable, Lockable {
/**
- * Gets only the DMAAP Topic Sources.
+ * Gets only the KAFKA Topic Sources.
*
@@ -234,21 +205,14 @@ public interface TopicEndpoint extends Startable, Lockable {
*
- * @return the DMAAP Topic Source List
+ * @return the KAFKA Topic Source List
*/
@@ -258,18 +222,11 @@ public interface TopicEndpoint extends Startable, Lockable {
List<NoopTopicSource> getNoopTopicSources();
/**
- * Gets only the UEB Topic Sinks.
+ * Gets only the KAFKA Topic Sinks.
*
@@ -258,18 +222,11 @@ public interface TopicEndpoint extends Startable, Lockable {
*
- * @return the UEB Topic Sink List
+ * @return the KAFKA Topic Sinks List
*/